@@ -105,13 +105,12 @@ AddTransportDialog::AddTransportDialog(QWidget *parent)
 {
     // Setup UI.
     {
-        QVBoxLayout *mainLayout = new QVBoxLayout;
-        setLayout(mainLayout);
+        QVBoxLayout *mainLayout = new QVBoxLayout(this);
         QWidget *widget = new QWidget(this);
         d->ui.setupUi(widget);
         mainLayout->addWidget(widget);
         setWindowTitle(i18n("Create Outgoing Account"));
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
         d->okButton = buttonBox->button(QDialogButtonBox::Ok);
         d->okButton->setText(i18nc("create and configure a mail transport", "Create and Configure"));
         d->okButton->setEnabled(false);
